# Changelog

<!--next-version-placeholder-->

## v0.1.1 (2022-08-10)
### Fix
* Wrong release version ([`3acaab8`](https://github.com/haoxiangsnr/audioinfo/commit/3acaab87631e7b12a4cd887d74daee84a305e6b2))
* Lower version ([`a92fda3`](https://github.com/haoxiangsnr/audioinfo/commit/a92fda3b930de43f2d2231b0169a7a6821768a7e))

## v0.1.0 (2022-08-10)
### Feature
* Initial audioinfo ([`78816b7`](https://github.com/haoxiangsnr/audioinfo/commit/78816b72eb4a00ca1ded67be2dcec522f064f96e))